==> haskell-src-meta-0.8.14-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-meta
version:              0.8.14
visibility:           public
id:                   haskell-src-meta-0.8.14-1six67SZmHc8alzSueF00c
key:                  haskell-src-meta-0.8.14-1six67SZmHc8alzSueF00c
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  2120a4083fd21c39931934d722398897
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.14-1six67SZmHc8alzSueF00c
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-KZofqn8v8UTLZiWXdrS8AG
    pretty-1.1.3.6 syb-0.7.2.4-FxOA5ryuuOlLotDfjBKcFb
    template-haskell-2.19.0.0 th-orphans-0.13.14-DNsl9Mddwd7APcIFTx6vxG

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.8.14-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-meta
version:              0.8.14
visibility:           public
id:                   haskell-src-meta-0.8.14-GdjTONg9iL7Eecbky51SBN
key:                  haskell-src-meta-0.8.14-GdjTONg9iL7Eecbky51SBN
license:              BSD-3-Clause
copyright:            (c) Matt Morrow
maintainer:           danburton.email@gmail.com
author:               Matt Morrow
synopsis:             Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.

category:             Language, Template Haskell
abi:                  204c7948d2595955ddd90ea981a2724f
exposed:              True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Extensions
    Language.Haskell.Meta.Parse Language.Haskell.Meta.Syntax.Translate
    Language.Haskell.Meta.Utils

hidden-modules:       Language.Haskell.Meta.THCompat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-meta-0.8.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-meta
hs-libraries:         HShaskell-src-meta-0.8.14-GdjTONg9iL7Eecbky51SBN
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-KZofqn8v8UTLZiWXdrS8AG
    pretty-1.1.3.6 syb-0.7.2.4-FxOA5ryuuOlLotDfjBKcFb
    template-haskell-2.19.0.0 th-orphans-0.13.14-DrCGv3hx1MjCKbjdUR4PRX

haddock-interfaces:
    /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock

haddock-html:         /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
